==> mmaid-0.1.3.tar.gz: mmaid-0.1.3/src/general.h <==
/*
    Melody maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __GENERAL_H__
#define __GENERAL_H__


#include "mmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:一般関数群                                                               *
*                                                                             *
******************************************************************************/
/*  ja:メニューを設定する
    mmaid,ウインドウ情報                                                    */
void
set_menu_bar (MmaidWindow *mmaid);


/*  ja:ファイルの保存を問い合わせる
    mmaid,ウインドウ情報
      RET,TRUE:ファイルは閉じる,FALSE:ファイルを閉じない                    */
gboolean
prompt_close (MmaidWindow *mmaid);


/*  ja:文字符号化方式を置換する
    charlist,置換する文字符号化方式                                         */
void
charlist_renewal_all (const gchar *charlist);


/******************************************************************************
*                                                                             *
* ja:項目関数群                                                               *
*                                                                             *
******************************************************************************/
/*  ja:タグを比較する
    id3tag0,タグ0
    id3tag1,タグ1
        RET,TRUE:等しい,FALSE:異なる                                        */
gboolean
cmp_id3tag (const ID3Tag *id3tag0,
            const ID3Tag *id3tag1);


/*  ja:タグをコピーする
    id3tag,タグ
       RET,タグ                                                             */
ID3Tag *
copy_id3tag (const ID3Tag *id3tag);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GENERAL_H__ */

==> mmaid-0.3.2.tar.gz: mmaid-0.3.2/src/general.h <==
/*
    Melody maid
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __GENERAL_H__
#define __GENERAL_H__


#include "mmaid.h"


G_BEGIN_DECLS


/******************************************************************************
*                                                                             *
* ja:一般関数群                                                               *
*                                                                             *
******************************************************************************/
/*  ja:メニューを設定する
    mmaid,ウインドウ情報                                                    */
void
set_menu_bar (MmaidWindow *mmaid);


/*  ja:ファイルの保存を問い合わせる
    mmaid,ウインドウ情報
      RET,TRUE:ファイルは閉じる,FALSE:ファイルを閉じない                    */
gboolean
prompt_close (MmaidWindow *mmaid);


/*  ja:文字符号化方式を置換する
    charlist,置換する文字符号化方式                                         */
void
charlist_renewal_all (const gchar *charlist);


/******************************************************************************
*                                                                             *
* ja:項目関数群                                                               *
*                                                                             *
******************************************************************************/
/*  ja:タグを比較する
    id3tag0,タグ0
    id3tag1,タグ1
        RET,TRUE:等しい,FALSE:異なる                                        */
gboolean
cmp_id3tag (const ID3Tag *id3tag0,
            const ID3Tag *id3tag1);


/*  ja:タグをコピーする
    id3tag,タグ
       RET,タグ                                                             */
ID3Tag *
copy_id3tag (const ID3Tag *id3tag);


G_END_DECLS


#endif /* __GENERAL_H__ */
